# bolero-process

[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[badge-tests]: https://img.shields.io/github/actions/workflow/status/lhqing/bolero-process/test.yaml?branch=main
[link-tests]: https://github.com/lhqing/bolero-process/actions/workflows/test.yml
[badge-docs]: https://img.shields.io/readthedocs/bolero-process

Data preprocessing for bolero package

## Getting started

Please refer to the [documentation][link-docs]. In particular, the

-   [API documentation][link-api].

## Installation

You need to have Python 3.9 or newer installed on your system. If you don't have
Python installed, we recommend installing [Mambaforge](https://github.com/conda-forge/miniforge#mambaforge).

There are several alternative options to install bolero-process:

<!--
1) Install the latest release of `bolero-process` from `PyPI <https://pypi.org/project/bolero-process/>`_:

```bash
pip install bolero-process
```
-->

1. Install the latest development version:

```bash
pip install git+https://github.com/lhqing/bolero-process.git@main
```

## Release notes

See the [changelog][changelog].

## Contact

For questions and help requests, you can reach out in the [scverse discourse][scverse-discourse].
If you found a bug, please use the [issue tracker][issue-tracker].

## Citation

> t.b.a

[scverse-discourse]: https://discourse.scverse.org/
[issue-tracker]: https://github.com/lhqing/bolero-process/issues
[changelog]: https://bolero-process.readthedocs.io/latest/changelog.html
[link-docs]: https://bolero-process.readthedocs.io
[link-api]: https://bolero-process.readthedocs.io/latest/api.html
